import Config from './config'
import { DynamoDBClient, DynamoDBClientConfig, CreateTableCommandInput } from "@aws-sdk/client-dynamodb"
import {  TableCreataorI } from './tableCreator';

let dynamoDBData: DynamoDBClientConfig = {
    apiVersion: Config.getApiVersion(),
    region: Config.getRegion(),
    endpoint: Config.getEndpoint()
}
const isTest = process.env.JEST_WORKER_ID;

if (isTest) {
    dynamoDBData = {
        endpoint: 'http://localhost:8000',
        //@ts-ignore
        sslEnabled: false,
        region: 'local-env',
    }
}

export const getDynamoDBParams = () => dynamoDBData

export interface TableProviderI {
    provide(): Promise<CreateTableCommandInput>
}

class DDB {
    instance: DynamoDBClient;

    constructor(dynamoDBDataParam: DynamoDBClientConfig) {
        this.instance = new DynamoDBClient(dynamoDBDataParam)
    }

    async createTable(provider: TableProviderI, tableCreator: TableCreataorI): Promise<boolean> {
        return tableCreator.createTable(this, await provider.provide())
    }
}

export default DDB

